@@ -8,33 +8,34 @@
 extern "C" {
 #endif
 
-/*
-  Typedef declarations.
-*/
 typedef struct _ViewInfo
 {
-  unsigned int
-    id;
-
   Image
     *image;
 
+  unsigned long
+    id;
+
   unsigned long
     signature;
 } ViewInfo;
-
-/*
-  MagickExport cache view interfaces.
-*/
+
+extern MagickExport const PixelPacket
+  *AcquireCacheView(const ViewInfo *,const long,const long,const unsigned long,
+    const unsigned long,ExceptionInfo *);
+
+extern MagickExport ExceptionInfo
+  *GetCacheViewException(const ViewInfo *);
+
 extern MagickExport IndexPacket
   *GetCacheViewIndexes(const ViewInfo *);
 
 extern MagickExport PixelPacket
   *GetCacheViewPixels(const ViewInfo *),
-  *GetCacheView(ViewInfo *,const int,const int,const unsigned int,
-    const unsigned int),
-  *SetCacheView(ViewInfo *,const int,const int,const unsigned int,
-    const unsigned int);
+  *GetCacheView(ViewInfo *,const long,const long,const unsigned long,
+    const unsigned long),
+  *SetCacheView(ViewInfo *,const long,const long,const unsigned long,
+    const unsigned long);
 
 extern MagickExport unsigned int
   SyncCacheView(ViewInfo *);
